#include "CreditsMenu.h"

MENU_SINGLETON_INIT(Credits);

//----------------------------------------------------------------------
CreditsMenu::CreditsMenu()
{
  getWidget(ID_CREDITS_MENU_BACK)->SetEventObject(
    MSG_BUTTONCLICK, this, (MSG_CALLBACK_OBJ)&CreditsMenu::onReturn);

  // Always show all child widgets.
  getWidget(ID_CREDITS_MENU_MAINT)->Show();
  getWidget(ID_CREDITS_MENU_MAINT_LST)->Show();
  getWidget(ID_CREDITS_MENU_MAINT_BT)->Show();
  getWidget(ID_CREDITS_MENU_PROG)->Show();
  getWidget(ID_CREDITS_MENU_PROG_LST)->Show();
  getWidget(ID_CREDITS_MENU_PROG_BT)->Show();
  getWidget(ID_CREDITS_MENU_PROG_AG)->Show();
  getWidget(ID_CREDITS_MENU_BACK)->Show();
}

//----------------------------------------------------------------------
CreditsMenu::~CreditsMenu()
{
}

//----------------------------------------------------------------------
PARAGUI_CALLBACK(CreditsMenu::onReturn)
{
  MenuManager::getInstance()->changeTo(getPrevious());
  return true;
}

//----------------------------------------------------------------------
void CreditsMenu::eventShow()
{
  getWidget(ID_CREDITS_MENU)->Show();
}

//----------------------------------------------------------------------
void CreditsMenu::eventHide()
{
  getWidget(ID_CREDITS_MENU)->Hide();
}
